import express from 'express';
import logger from 'morgan';
import Bourne from 'bourne';
import path from 'path';
import graphqlHTTP from 'express-graphql';
import {buildSchema} from 'graphql';
import {importSchema} from 'graphql-import';
import {connectionFromArray} from 'graphql-relay';

const app = express();

app.use(logger('dev'));
app.use(express.static('public'));

const recipes = new Bourne('db/recipes.json');

// Construct a schema, using GraphQL schema language
const schemaDef = importSchema(path.resolve('schema.graphql'));
const schema = buildSchema(schemaDef);

// The root provides a resolver function for each API endpoint
const root = {
  recipes(connArgs) {
    let conn = {};
    recipes.find((err, results) => {
      conn = connectionFromArray(results, connArgs);
    });
    return conn;
  }
};

app.use('/graphql', graphqlHTTP({
  schema,
  rootValue: root,
  graphiql: true
}));

app.listen(3000, () => console.log(`Application running at 'http://localhost:3000'`));
